"""Test the hyperparameters module.

Attribution
-----------

This code has been adapted from the scikit-learn project. Details of original source
material and how to access are provided below:

- Repository:    https://github.com/scikit-learn/scikit-learn
- Commit:        ed3642014be412b0bda13d1ec756baeabb0dcbfe
- File Path:     sklearn/model_selection/tests/test_search.py
- License:       BSD 3 Clause
- Access Date:   11 July 2021
- Adapted By:    Richard Izzo (rlizzo)
- License Text:  Please refer to NOTICE file in this repository for full
                 text of original source license.
"""
from collections.abc import Iterable, Sized
from functools import partial
from itertools import chain, product

import pytest

scipy_stats = pytest.importorskip("scipy.stats")

from grid.sdk.sweeps.grid_search_strategy import ParameterGrid, ParameterSampler


def assert_grid_iter_equals_getitem(grid):
    assert list(grid) == [grid[i] for i in range(len(grid))]


@pytest.mark.parametrize("klass", [ParameterGrid, partial(ParameterSampler, n_iter=10)])
@pytest.mark.parametrize(
    "input, error_type, error_message",
    [
        (0, TypeError, r"Parameter .* is not a dict or a list \(0\)"),
        ([{
            "foo": [0]
        }, 0], TypeError, r"Parameter .* is not a dict \(0\)"),
        (
            {
                "foo": 0
            },
            TypeError,
            "Parameter.* value is not iterable .*"
            r"\(key='foo', value=0\)",
        ),
    ],
)
def test_validate_parameter_input(klass, input, error_type, error_message):
    with pytest.raises(error_type, match=error_message):
        klass(input)


def test_parameter_grid():

    # Test basic properties of ParameterGrid.
    params1 = {"foo": [1, 2, 3]}
    grid1 = ParameterGrid(params1)
    assert isinstance(grid1, Iterable)
    assert isinstance(grid1, Sized)
    assert len(grid1) == 3
    assert_grid_iter_equals_getitem(grid1)

    params2 = {"foo": [4, 2], "bar": ["ham", "spam", "eggs"]}
    grid2 = ParameterGrid(params2)
    assert len(grid2) == 6

    # loop to assert we can iterate over the grid multiple times
    for i in range(2):
        # tuple + chain transforms {"a": 1, "b": 2} to ("a", 1, "b", 2)
        points = set(tuple(chain(*(sorted(p.items())))) for p in grid2)
        assert points == set(("bar", x, "foo", y) for x, y in product(params2["bar"], params2["foo"]))
    assert_grid_iter_equals_getitem(grid2)

    # Special case: empty grid (useful to get default estimator settings)
    empty = ParameterGrid({})
    assert len(empty) == 1
    assert list(empty) == [{}]
    assert_grid_iter_equals_getitem(empty)
    with pytest.raises(IndexError):
        _ = empty[1]

    has_empty = ParameterGrid([{"C": [1, 10]}, {}, {"C": [0.5]}])
    assert len(has_empty) == 4
    assert list(has_empty) == [{"C": 1}, {"C": 10}, {}, {"C": 0.5}]
    assert_grid_iter_equals_getitem(has_empty)


def test_param_sampler():
    # test basic properties of param sampler
    param_distributions = {"kernel": ["rbf", "linear"], "C": scipy_stats.uniform(0, 1)}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=10, random_state=0)
    samples = [x for x in sampler]
    assert len(samples) == 10
    for sample in samples:
        assert sample["kernel"] in ["rbf", "linear"]
        assert 0 <= sample["C"] <= 1

    # test that repeated calls yield identical parameters
    param_distributions = {"C": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=3, random_state=0)
    assert [x for x in sampler] == [x for x in sampler]

    param_distributions = {"C": scipy_stats.uniform(0, 1)}
    sampler = ParameterSampler(param_distributions=param_distributions, n_iter=10, random_state=0)
    assert [x for x in sampler] == [x for x in sampler]


def test_parameters_sampler_replacement():
    # raise warning if n_iter is bigger than total parameter space
    params = [
        {
            "first": [0, 1],
            "second": ["a", "b", "c"]
        },
        {
            "third": ["two", "values"]
        },
    ]
    sampler = ParameterSampler(params, n_iter=9)
    n_iter = 9
    grid_size = 8
    expected_warning = (
        "The total space of parameters %d is smaller "
        "than n_iter=%d. Running %d iterations. For "
        "exhaustive searches, use GridSearchCV." % (grid_size, n_iter, grid_size)
    )
    with pytest.warns(UserWarning, match=expected_warning):
        list(sampler)

    # degenerates to GridSearchCV if n_iter the same as grid_size
    sampler = ParameterSampler(params, n_iter=8)
    samples = list(sampler)
    assert len(samples) == 8
    for values in ParameterGrid(params):
        assert values in samples
    assert len(ParameterSampler(params, n_iter=1000)) == 8

    # test sampling without replacement in a large grid
    params = {"a": range(10), "b": range(10), "c": range(10)}
    sampler = ParameterSampler(params, n_iter=99, random_state=42)
    samples = list(sampler)
    assert len(samples) == 99
    hashable_samples = ["a%db%dc%d" % (p["a"], p["b"], p["c"]) for p in samples]
    assert len(set(hashable_samples)) == 99

    # doesn't go into infinite loops
    params_distribution = {"first": scipy_stats.bernoulli(0.5), "second": ["a", "b", "c"]}
    sampler = ParameterSampler(params_distribution, n_iter=7)
    samples = list(sampler)
    assert len(samples) == 7



import os

GRID_URL = os.getenv("GRID_URL", 'https://platform.grid.ai')

TERMINAL_STATES = {"CANCELLED", "FAILED", "SUCCEEDED"}
STARTED_STATES = {"RUNNING", *TERMINAL_STATES}
WAITING_STATES = {"PENDING"}
IGNORE_WARNINGS = None



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/suspicious_activity.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/suspicious_activity.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n!grid/v1/suspicious_activity.proto\x12\x07grid.v1\"\xfc\x01\n\x1fReportSuspiciousActivityRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12\x18\n\x07\x64\x65tails\x18\x05 \x01(\tR\x07\x64\x65tails\x12:\n\rresource_type\x18\x06 \x01(\x0e\x32\x15.grid.v1.ResourceTypeR\x0cresourceType\x12\x1f\n\x0bresource_id\x18\x07 \x01(\tR\nresourceId\"\"\n ReportSuspiciousActivityResponse*f\n\x0cResourceType\x12\x1d\n\x19RESOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15RESOURCE_TYPE_SESSION\x10\x01\x12\x1c\n\x18RESOURCE_TYPE_EXPERIMENT\x10\x02\x32\x8c\x01\n\x19SuspiciousActivityService\x12o\n\x18ReportSuspiciousActivity\x12(.grid.v1.ReportSuspiciousActivityRequest\x1a).grid.v1.ReportSuspiciousActivityResponseB2Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
)

_RESOURCETYPE = _descriptor.EnumDescriptor(
    name='ResourceType',
    full_name='grid.v1.ResourceType',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_SESSION',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='RESOURCE_TYPE_EXPERIMENT',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=337,
    serialized_end=439,
)
_sym_db.RegisterEnumDescriptor(_RESOURCETYPE)

ResourceType = enum_type_wrapper.EnumTypeWrapper(_RESOURCETYPE)
RESOURCE_TYPE_UNSPECIFIED = 0
RESOURCE_TYPE_SESSION = 1
RESOURCE_TYPE_EXPERIMENT = 2

_REPORTSUSPICIOUSACTIVITYREQUEST = _descriptor.Descriptor(
    name='ReportSuspiciousActivityRequest',
    full_name='grid.v1.ReportSuspiciousActivityRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.cluster_id',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='type',
            full_name='grid.v1.ReportSuspiciousActivityRequest.type',
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='type',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='reason',
            full_name='grid.v1.ReportSuspiciousActivityRequest.reason',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='reason',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='details',
            full_name='grid.v1.ReportSuspiciousActivityRequest.details',
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='details',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_type',
            full_name='grid.v1.ReportSuspiciousActivityRequest.resource_type',
            index=5,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resource_id',
            full_name='grid.v1.ReportSuspiciousActivityRequest.resource_id',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resourceId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=47,
    serialized_end=299,
)

_REPORTSUSPICIOUSACTIVITYRESPONSE = _descriptor.Descriptor(
    name='ReportSuspiciousActivityResponse',
    full_name='grid.v1.ReportSuspiciousActivityResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=301,
    serialized_end=335,
)

_REPORTSUSPICIOUSACTIVITYREQUEST.fields_by_name['resource_type'].enum_type = _RESOURCETYPE
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityRequest'] = _REPORTSUSPICIOUSACTIVITYREQUEST
DESCRIPTOR.message_types_by_name['ReportSuspiciousActivityResponse'] = _REPORTSUSPICIOUSACTIVITYRESPONSE
DESCRIPTOR.enum_types_by_name['ResourceType'] = _RESOURCETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReportSuspiciousActivityRequest = _reflection.GeneratedProtocolMessageType(
    'ReportSuspiciousActivityRequest',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REPORTSUSPICIOUSACTIVITYREQUEST,
        '__module__': 'grid.v1.suspicious_activity_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityRequest)
    }
)
_sym_db.RegisterMessage(ReportSuspiciousActivityRequest)

ReportSuspiciousActivityResponse = _reflection.GeneratedProtocolMessageType(
    'ReportSuspiciousActivityResponse',
    (_message.Message, ),
    {
        'DESCRIPTOR': _REPORTSUSPICIOUSACTIVITYRESPONSE,
        '__module__': 'grid.v1.suspicious_activity_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ReportSuspiciousActivityResponse)
    }
)
_sym_db.RegisterMessage(ReportSuspiciousActivityResponse)

DESCRIPTOR._options = None

_SUSPICIOUSACTIVITYSERVICE = _descriptor.ServiceDescriptor(
    name='SuspiciousActivityService',
    full_name='grid.v1.SuspiciousActivityService',
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=442,
    serialized_end=582,
    methods=[
        _descriptor.MethodDescriptor(
            name='ReportSuspiciousActivity',
            full_name='grid.v1.SuspiciousActivityService.ReportSuspiciousActivity',
            index=0,
            containing_service=None,
            input_type=_REPORTSUSPICIOUSACTIVITYREQUEST,
            output_type=_REPORTSUSPICIOUSACTIVITYRESPONSE,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ]
)
_sym_db.RegisterServiceDescriptor(_SUSPICIOUSACTIVITYSERVICE)

DESCRIPTOR.services_by_name['SuspiciousActivityService'] = _SUSPICIOUSACTIVITYSERVICE

# @@protoc_insertion_point(module_scope)



from datetime import datetime, timezone
from typing import Dict, Optional

import click
from dateutil.parser import parse as date_string_parse
from gql import Client, gql
from gql.transport.exceptions import TransportQueryError

import grid.cli.globals as env
from grid.cli.observables.base import BaseObservable
from grid.cli.utilities import get_abs_time_difference, string_format_date, string_format_timedelta


def get_runs(client: Client, run_name: Optional[str], team_id: Optional[str] = None) -> Dict:

    params = {'runName': run_name, "teamId": team_id}

    query = gql(
        """
        query (
            $runName: ID, $teamId: ID
        ) {
            getRuns (runName: $runName, teamId: $teamId) {
                name
                createdAt
                experiments {
                    experimentId
                }
                nExperiments
                nFailed
                nCancelled
                nRunning
                nCompleted
                nQueued
                nPending
                projectId
                userDetails {
                    username
                }
            }
        }
        """
    )

    result = client.execute(query, variable_values=params)
    return result['getRuns']


def get_runs_history(client: Client, run_name: Optional[str], team_id: Optional[str] = None) -> Dict:

    params = {'runName': run_name, "teamId": team_id}

    query = gql(
        """
         query (
            $runName: ID, $teamId: ID
        ) {
            getRuns (runName: $runName, teamId: $teamId) {
                name
                createdAt
                experiments {
                    experimentId
                }
                nExperiments
                nFailed
                nCancelled
                nRunning
                nCompleted
                nQueued
                userDetails {
                    username
                }
            }
        }
        """
    )

    result = client.execute(query, variable_values=params)
    return result['getRuns']


class Run(BaseObservable):
    def __init__(self, client: Client, identifier: Optional[str] = []):
        self.client = client

        self.identifier = identifier

        super().__init__(client=client, spinner_load_type="Runs")

    def get(self, is_global: Optional[bool] = False):
        """
        Gets the run status; either for a single run or all runs for
        user.

        Parameters
        ----------
        is_global: Optional[bool], default False
            if True, returns status of experiment(s) of the everyone in the team (TODO)
        """
        runs = []
        self.spinner.start()
        self.spinner.text = 'Getting Run status...'

        run_name = None
        if self.identifier:
            run_name = self.identifier

        try:
            if is_global:
                from grid.cli.core.team import Team
                teams = Team.get_all()
                for team in teams:
                    team_runs = get_runs(self.client, run_name=run_name, team_id=team.id)
                    runs.extend(team_runs)
            else:
                runs = get_runs(self.client, run_name=run_name, team_id=None)
            self.spinner.text = 'Done!'
        except TransportQueryError as e:
            self.spinner.fail("✘")
            self.spinner.stop()
            if env.DEBUG:
                click.echo(str(e))

            raise click.ClickException('Query to Grid failed. Try again in a few minutes.')

        if is_global:
            table_cols = [
                'Run',
                'Project',
                'Status',
                'Created By',
                'Duration',
                'Experiments',
                'Running',
                'Queued',
                'Completed',
                'Failed',
                'Stopped',
            ]
        else:
            table_cols = [
                'Run',
                'Project',
                'Status',
                'Duration',
                'Experiments',
                'Running',
                'Queued',
                'Completed',
                'Failed',
                'Stopped',
            ]

        table = BaseObservable.create_table(columns=table_cols)

        #  Whenever we don't have yet submitted experiments,
        table_rows = 0
        for row in runs:
            status = None

            # we only have 3 statuses for runs
            # running (if something is running)
            is_running = row['nRunning'] is not None and row['nRunning'] > 0

            # We classify queued and pending into queued
            queued = row['nQueued']
            pending = row['nPending']
            n_queued = queued + pending

            # If anything is queued, the the status of the entire
            # run is queued. All other statuses are running in
            # all other conditions.
            if n_queued > 0:
                status = 'queued'

            # If you have anything running (and nothing queued)
            # then, mark the run as running.
            elif is_running:
                status = 'running'

            # If it doesn't match the conditions above, just
            # skip this row and add the row and put it in history.
            else:
                # don't render table because it should be in history
                continue

            #  Change the printed key from `None` to `-` if the
            #  no data exists for those keys.
            keys = ['nExperiments', 'nRunning', 'nQueued', 'nCompleted', 'nFailed', 'nCancelled']
            for key in keys:
                if row[key] is None:
                    row[key] = '-'

            # Calculate the duration column
            created_at = date_string_parse(row['createdAt'])
            delta = get_abs_time_difference(datetime.now(timezone.utc), created_at)
            duration_str = string_format_timedelta(delta)

            if is_global:
                table.add_row(
                    row['name'], row['projectId'], status, row['userDetails']['username'], duration_str,
                    str(row['nExperiments']), str(row['nRunning']), str(n_queued), str(row['nCompleted']),
                    str(row['nFailed']), str(row['nCancelled'])
                )
            else:
                table.add_row(
                    row['name'], row['projectId'], status, duration_str, str(row['nExperiments']), str(row['nRunning']),
                    str(n_queued), str(row['nCompleted']), str(row['nFailed']), str(row['nCancelled'])
                )

            #  Let's count how many rows have been added.
            table_rows += 1

        #  Close the spinner.
        self.spinner.ok("✔")
        self.spinner.stop()

        # If there are no Runs to render, add a
        # placeholder row indicating none are active.
        if table_rows == 0:
            table.add_row("None Active.", *[" " for i in range(len(table_cols) - 1)])

        self.console.print(table)

        #  Print useful message indicating that users can run
        #  grid history.
        history_runs = len(runs) - table_rows
        if history_runs > 0:
            click.echo(f'{history_runs} Run(s) are not active. Use `grid history` ' 'to view your Run history.\n')

        return {'getRuns': runs}

    def get_history(self, is_global: Optional[bool] = False):
        """
        Fetches a complete history of runs. This includes runs that
        are not currently active.

        Parameters
        ----------
        is_global: Optional[bool], default False
            Returns status of session from everyone in the team
        """
        runs = []
        self.spinner.start()
        self.spinner.text = 'Getting Runs ...'

        run_name = None
        if self.identifier:
            run_name = self.identifier[0]

        try:
            if is_global:
                from grid.cli.core.team import Team
                teams = Team.get_all()
                for team in teams:
                    team_runs = get_runs_history(self.client, run_name=run_name, team_id=team.id)
                    runs.extend(team_runs)
            else:
                runs = get_runs_history(self.client, run_name=run_name, team_id=None)
            self.spinner.text = 'Done!'
            self.spinner.ok("✔")
            self.spinner.stop()
        except TransportQueryError as e:
            self.spinner.fail("✘")
            self.spinner.stop()
            if env.DEBUG:
                click.echo(str(e))

            raise click.ClickException('Query to Grid failed. Try again in a few minutes.')

        if is_global:
            table_cols = ['Run', 'Created By', 'Created At', 'Experiments', 'Failed', 'Stopped', 'Completed']
        else:
            table_cols = ['Run', 'Created At', 'Experiments', 'Failed', 'Stopped', 'Completed']
        table = BaseObservable.create_table(columns=table_cols)

        #  Whenever we don't have yet submitted experiments,
        table_rows = runs
        for row in table_rows:
            keys = ['nExperiments', 'nFailed', 'nCancelled', 'nCompleted']
            for key in keys:
                if row[key] is None:
                    row[key] = '-'

            # check if it is running
            is_running = row['nRunning'] is not None and row['nRunning'] > 0

            # check if queued
            is_queued = row['nQueued'] is not None and row['nQueued'] > 0

            # history is everything else
            if is_queued or is_running:
                continue

            created_at = string_format_date(date_string_parse(row['createdAt']))

            if is_global:
                table.add_row(
                    row['name'], row['userDetails']['username'], created_at, str(row['nExperiments']),
                    str(row['nFailed']), str(row['nCancelled']), str(row['nCompleted'])
                )
            else:
                table.add_row(
                    row['name'], created_at, str(row['nExperiments']), str(row['nFailed']), str(row['nCancelled']),
                    str(row['nCompleted'])
                )

        # Add placeholder row if no records are available.
        if not table_rows:
            table.add_row("No History.", *[" " for i in range(len(table_cols) - 1)])

        self.console.print(table)

        return runs

    def follow(self, is_global: Optional[bool] = False):  # pragma: no cover
        pass

    def _get_task_run_dependencies(self, run_name: str):
        """Gets dependency data for a given Run"""
        query = gql(
            """
        query (
            $runName: ID!
        ) {
            getRunTaskStatus (
                runName: $runName
            ) {
                success
                message
                runId
                name
                dependencies {
                    taskId
                    status
                    taskType
                    message
                    error
                }
            }
        }
        """
        )
        params = {'runName': run_name}

        #  Make GraphQL query.
        result = None
        try:
            result = self.client.execute(query, variable_values=params)
            if not result['getRunTaskStatus']['success']:
                raise Exception(result['getRunTaskStatus'])
        except Exception as e:  # skipcq: PYL-W0703
            self.spinner.fail("✘")
            self.spinner.stop()

            raise click.ClickException(f'Could not retrieve task dependencies. Error: {str(e)}')

        if result:
            dependencies = result['getRunTaskStatus']['dependencies']
            return dependencies
        return None



"""This module includes methods to fine-tune the parameters of a sweep.

The grid search provided by GridSearchCV exhaustively generates candidates
from a grid of parameter values specified with the param_grid parameter.
For instance, the following param_grid:

param_grid = [
  {'C': [1, 10, 100, 1000], 'kernel': ['linear']},
  {'C': [1, 10, 100, 1000], 'gamma': [0.001, 0.0001], 'kernel': ['rbf']},
 ]

specifies that two grids should be explored: one with a linear kernel and C
values in [1, 10, 100, 1000], and the second one with an RBF kernel, and the
cross-product of C values ranging in [1, 10, 100, 1000] and gamma values
in [0.001, 0.0001].

Attribution
-----------

This code has been adapted from the scikit-learn project. Details of original source
material and how to access are provided below:

- Repository:    https://github.com/scikit-learn/scikit-learn
- Commit:        ed3642014be412b0bda13d1ec756baeabb0dcbfe
- File Path:     sklearn/model_selection/_search.py
- License:       BSD 3 Clause
- Access Date:   11 July 2021
- Adapted By:    Richard Izzo (rlizzo)
- License Text:  Please refer to NOTICE file in this repository for full
                 text of original source license.
"""
from functools import partial, reduce
from itertools import product
import operator
from typing import Any, Iterable, Mapping, Optional, Sequence, Union
import warnings

import numpy as np

from grid.sdk.sweeps.sampling import check_random_state, sample_without_replacement


class ParameterGrid:
    """Grid of parameters with a discrete number of values for each.

    Can be used to iterate over parameter value combinations with the
    Python built-in function iter.

    The order of the generated parameter combinations is deterministic.
    Read more in the :ref:`User Guide <grid_search>`.

    Parameters
    ----------
    param_grid
        The parameter grid to explore, as a dictionary mapping estimator
        parameters to sequences of allowed values.

        An empty dict signifies default parameters.

        A sequence of dicts signifies a sequence of grids to search, and is
        useful to avoid exploring parameter combinations that make no sense
        or have no effect. See the examples below.

    Examples
    --------
    >>> from grid.sdk.sweeps.grid_search_strategy import ParameterGrid
    >>> param_grid = {'a': [1, 2], 'b': [True, False]}
    >>> list(ParameterGrid(param_grid)) == (
    ...    [{'a': 1, 'b': True}, {'a': 1, 'b': False},
    ...     {'a': 2, 'b': True}, {'a': 2, 'b': False}])
    True
    >>> grid = [{'kernel': ['linear']}, {'kernel': ['rbf'], 'gamma': [1, 10]}]
    >>> list(ParameterGrid(grid)) == [{'kernel': 'linear'},
    ...                               {'kernel': 'rbf', 'gamma': 1},
    ...                               {'kernel': 'rbf', 'gamma': 10}]
    True
    >>> ParameterGrid(grid)[1] == {'kernel': 'rbf', 'gamma': 1}
    True

    See Also
    --------
    GridSearchCV : Uses :class:`ParameterGrid` to perform a full parallelized
        parameter search.
    """
    def __init__(self, param_grid: Union[Mapping[str, Sequence], Sequence[Mapping[str, Sequence]]]):
        if not isinstance(param_grid, (Mapping, Iterable)):
            raise TypeError("Parameter grid is not a dict or a list ({!r})".format(param_grid))

        if isinstance(param_grid, Mapping):
            # wrap dictionary in a singleton list to support either dict
            # or list of dicts
            param_grid = [param_grid]

        # check if all entries are dictionaries of lists
        for grid in param_grid:
            if not isinstance(grid, dict):
                raise TypeError("Parameter grid is not a dict ({!r})".format(grid))
            for key in grid:
                if not isinstance(grid[key], Iterable):
                    raise TypeError(
                        "Parameter grid value is not iterable "
                        "(key={!r}, value={!r})".format(key, grid[key])
                    )

        self.param_grid = param_grid

    def __iter__(self):
        """Iterate over the points in the grid.
        Returns
        -------
        params : iterator over dict of str to any
            Yields dictionaries mapping each estimator parameter to one of its
            allowed values.
        """
        for p in self.param_grid:
            # Always sort the keys of a dictionary, for reproducibility
            items = sorted(p.items())
            if not items:
                yield {}
            else:
                keys, values = zip(*items)
                for v in product(*values):
                    params = dict(zip(keys, v))
                    yield params

    def __len__(self):
        """Number of points on the grid."""
        # Product function that can handle iterables (np.product can't).
        _product = partial(reduce, operator.mul)
        return sum(_product(len(v) for v in p.values()) if p else 1 for p in self.param_grid)

    def __getitem__(self, ind: int):
        """Get the parameters that would be ``ind``th in iteration
        Parameters
        ----------
        ind
            The iteration index
        Returns
        -------
        params : dict of str to any
            Equal to list(self)[ind]
        """
        # This is used to make discrete sampling without replacement memory
        # efficient.
        for sub_grid in self.param_grid:
            # XXX: could memoize information used here
            if not sub_grid:
                if ind == 0:
                    return {}
                ind -= 1
                continue

            # Reverse so most frequent cycling parameter comes first
            keys, values_lists = zip(*sorted(sub_grid.items())[::-1])
            sizes = [len(v_list) for v_list in values_lists]
            total = np.product(sizes)

            if ind >= total:
                # Try the next grid
                ind -= total
            else:
                out = {}
                for key, v_list, n in zip(keys, values_lists, sizes):
                    ind, offset = divmod(ind, n)
                    out[key] = v_list[offset]
                return out

        raise IndexError("ParameterGrid index out of range")


class ParameterSampler:
    """Generator on parameters sampled from given distributions.

    Non-deterministic iterable over random candidate combinations for
    hyper-parameter search. If all parameters are presented as a list,
    sampling without replacement is performed. If at least one parameter
    is given as a distribution, sampling with replacement is used. It
    is highly recommended to use continuous distributions for continuous
    parameters.

    Read more in the :ref:`User Guide <grid_search>`.

    Parameters
    ----------
    param_distributions
        Dictionary with parameters names (`str`) as keys and distributions
        or lists of parameters to try. Distributions must provide a ``rvs``
        method for sampling (such as those from scipy.stats.distributions).

        If a list is given, it is sampled uniformly.

        If a list of dicts is given, first a dict is sampled uniformly, and
        then a parameter is sampled using that dict as above.

    n_iter : int
        Number of parameter settings that are produced.

    random_state : int, RandomState instance or None, default=None
        Pseudo random number generator state used for random uniform sampling
        from lists of possible values instead of scipy.stats distributions.

        Pass an int for reproducible output across multiple function calls.

    Returns
    -------
    params : dict of str to any
        **Yields** dictionaries mapping each estimator parameter to as sampled value.

    Examples
    --------
    >>> from grid.sdk.sweeps.grid_search_strategy import ParameterSampler
    >>> import numpy as np
    >>> import scipy.stats
    >>> rng = np.random.RandomState(0)
    >>> param_grid = {'a':[1, 2], 'b': scipy.stats.expon(scale=1.0)}
    >>> param_list = list(ParameterSampler(param_grid, n_iter=4, random_state=rng))
    >>> rounded_list = [dict((k, round(v, 6)) for (k, v) in d.items())
    ...                 for d in param_list]
    >>> rounded_list == [{'b': 0.89856, 'a': 1},
    ...                  {'b': 0.923223, 'a': 1},
    ...                  {'b': 1.878964, 'a': 2},
    ...                  {'b': 1.038159, 'a': 2}]
    True
    """
    def __init__(
        self,
        param_distributions: Union[Union[Mapping[str, Any], Sequence[Union[str, Any]]], Sequence[Any],
                                   Sequence[Mapping[str, Any]]],
        n_iter: int,
        *,
        random_state: Optional[Union[np.random.RandomState, int]] = None
    ):
        if not isinstance(param_distributions, (Mapping, Iterable)):
            raise TypeError("Parameter distribution is not a dict or a list ({!r})".format(param_distributions))

        if isinstance(param_distributions, Mapping):
            # wrap dictionary in a singleton list to support either dict
            # or list of dicts
            param_distributions = [param_distributions]

        for dist in param_distributions:
            if not isinstance(dist, dict):
                raise TypeError("Parameter distribution is not a dict ({!r})".format(dist))
            for key in dist:
                if not isinstance(dist[key], Iterable) and not hasattr(dist[key], "rvs"):
                    raise TypeError(
                        "Parameter value is not iterable "
                        "or distribution (key={!r}, value={!r})".format(key, dist[key])
                    )
        self.n_iter = n_iter
        self.random_state = random_state
        self.param_distributions = param_distributions

    def _is_all_lists(self):
        return all(all(not hasattr(v, "rvs") for v in dist.values()) for dist in self.param_distributions)

    def __iter__(self):
        rng = check_random_state(self.random_state)

        # if all distributions are given as lists, we want to sample without
        # replacement
        if self._is_all_lists():
            # look up sampled parameter settings in parameter grid
            param_grid = ParameterGrid(self.param_distributions)
            grid_size = len(param_grid)
            n_iter = self.n_iter

            if grid_size < n_iter:
                warnings.warn(
                    "The total space of parameters %d is smaller "
                    "than n_iter=%d. Running %d iterations. For exhaustive "
                    "searches, use GridSearchCV." % (grid_size, self.n_iter, grid_size),
                    UserWarning,
                )
                n_iter = grid_size
            for i in sample_without_replacement(grid_size, n_iter, random_state=rng):
                yield param_grid[i]

        else:
            for _ in range(self.n_iter):
                dist = rng.choice(self.param_distributions)
                # Always sort the keys of a dictionary, for reproducibility
                items = sorted(dist.items())
                params = {}
                for k, v in items:
                    if hasattr(v, "rvs"):
                        params[k] = v.rvs(random_state=rng)
                    else:
                        params[k] = v[rng.randint(len(v))]
                yield params

    def __len__(self):
        """Number of points that will be sampled."""
        if self._is_all_lists():
            grid_size = len(ParameterGrid(self.param_distributions))
            return min(self.n_iter, grid_size)
        return self.n_iter


def _check_param_grid(param_grid):
    if hasattr(param_grid, "items"):
        param_grid = [param_grid]

    for p in param_grid:
        for name, v in p.items():
            if isinstance(v, np.ndarray) and v.ndim > 1:
                raise ValueError("Parameter array should be one-dimensional.")

            if isinstance(v, str) or not isinstance(v, (np.ndarray, Sequence)):
                raise ValueError(
                    "Parameter grid for parameter ({0}) needs to"
                    " be a list or numpy array, but got ({1})."
                    " Single values need to be wrapped in a list"
                    " with one element.".format(name, type(v))
                )

            if len(v) == 0:
                raise ValueError(
                    "Parameter values for parameter ({0}) need "
                    "to be a non-empty sequence.".format(name)
                )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/datastore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/datastore.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x17grid/v1/datastore.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x98\x01\n\tDatastore\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12*\n\x04spec\x18\x02 \x01(\x0b\x32\x16.grid.v1.DatastoreSpecR\x04spec\x12\x30\n\x06status\x18\x03 \x01(\x0b\x32\x18.grid.v1.DatastoreStatusR\x06status\"\xfc\x02\n\rDatastoreSpec\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07version\x18\x03 \x01(\rR\x07version\x12\x30\n\x06source\x18\x04 \x01(\x0b\x32\x18.grid.v1.DatastoreSourceR\x06source\x12<\n\rdesired_state\x18\x05 \x01(\x0e\x32\x17.grid.v1.DatastoreStateR\x0c\x64\x65siredState\x12;\n\x0buploaded_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nuploadedAt\x12\x1d\n\ncluster_id\x18\x07 \x01(\tR\tclusterId\x12\x19\n\x08size_mib\x18\x08 \x01(\rR\x07sizeMib\x12=\n\x0e\x64\x61tastore_type\x18\t \x01(\x0e\x32\x16.grid.v1.DatastoreTypeR\rdatastoreType\"/\n\x0f\x44\x61tastoreSource\x12\x12\n\x03\x64sn\x18\x01 \x01(\tH\x00R\x03\x64snB\x08\n\x06source\"\xd0\x01\n\x0f\x44\x61tastoreStatus\x12:\n\x05phase\x18\x01 \x01(\x0e\x32$.grid.v1.DatastoreOptimizationStatusR\x05phase\x12\x1d\n\nsize_bytes\x18\x02 \x01(\x04R\tsizeBytes\x12=\n\x0bsnapshot_id\x18\x03 \x01(\x0b\x32\x1c.grid.v1.DatastoreSnapshotIDR\nsnapshotId\x12#\n\rextracted_url\x18\x04 \x01(\tR\x0c\x65xtractedUrl\"\x8a\x01\n\x13\x44\x61tastoreSnapshotID\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x39\n\x18k8s_volume_snapshot_name\x18\x02 \x01(\tH\x00R\x15k8sVolumeSnapshotNameB\x04\n\x02id\"A\n\x0e\x44\x61tastoreInput\x12\x10\n\x03\x64sn\x18\x01 \x01(\tR\x03\x64sn\x12\x1d\n\nmount_path\x18\x02 \x01(\tR\tmountPath*p\n\rDatastoreType\x12\x1e\n\x1a\x44\x41TASTORE_TYPE_UNSPECIFIED\x10\x00\x12$\n DATASTORE_TYPE_COMPRESSED_SOURCE\x10\x01\x12\x19\n\x15\x44\x41TASTORE_TYPE_FOLDER\x10\x02*\x8a\x01\n\x0e\x44\x61tastoreState\x12\x1f\n\x1b\x44\x41TASTORE_STATE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x41TASTORE_STATE_UPLOADING\x10\x01\x12\x1b\n\x17\x44\x41TASTORE_STATE_CREATED\x10\x02\x12\x1b\n\x17\x44\x41TASTORE_STATE_DELETED\x10\x03*\xfc\x01\n\x1b\x44\x61tastoreOptimizationStatus\x12-\n)DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED\x10\x00\x12+\n\'DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED\x10\x01\x12(\n$DATASTORE_OPTIMIZATION_STATUS_FAILED\x10\x02\x12,\n(DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING\x10\x03\x12)\n%DATASTORE_OPTIMIZATION_STATUS_DELETED\x10\x04\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_DATASTORETYPE = _descriptor.EnumDescriptor(
    name='DatastoreType',
    full_name='grid.v1.DatastoreType',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_TYPE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_TYPE_COMPRESSED_SOURCE',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_TYPE_FOLDER',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1126,
    serialized_end=1238,
)
_sym_db.RegisterEnumDescriptor(_DATASTORETYPE)

DatastoreType = enum_type_wrapper.EnumTypeWrapper(_DATASTORETYPE)
_DATASTORESTATE = _descriptor.EnumDescriptor(
    name='DatastoreState',
    full_name='grid.v1.DatastoreState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_STATE_UPLOADING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_STATE_CREATED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_STATE_DELETED',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1241,
    serialized_end=1379,
)
_sym_db.RegisterEnumDescriptor(_DATASTORESTATE)

DatastoreState = enum_type_wrapper.EnumTypeWrapper(_DATASTORESTATE)
_DATASTOREOPTIMIZATIONSTATUS = _descriptor.EnumDescriptor(
    name='DatastoreOptimizationStatus',
    full_name='grid.v1.DatastoreOptimizationStatus',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_OPTIMIZATION_STATUS_FAILED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='DATASTORE_OPTIMIZATION_STATUS_DELETED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1382,
    serialized_end=1634,
)
_sym_db.RegisterEnumDescriptor(_DATASTOREOPTIMIZATIONSTATUS)

DatastoreOptimizationStatus = enum_type_wrapper.EnumTypeWrapper(_DATASTOREOPTIMIZATIONSTATUS)
DATASTORE_TYPE_UNSPECIFIED = 0
DATASTORE_TYPE_COMPRESSED_SOURCE = 1
DATASTORE_TYPE_FOLDER = 2
DATASTORE_STATE_UNSPECIFIED = 0
DATASTORE_STATE_UPLOADING = 1
DATASTORE_STATE_CREATED = 2
DATASTORE_STATE_DELETED = 3
DATASTORE_OPTIMIZATION_STATUS_UNSPECIFIED = 0
DATASTORE_OPTIMIZATION_STATUS_SUCCEEDED = 1
DATASTORE_OPTIMIZATION_STATUS_FAILED = 2
DATASTORE_OPTIMIZATION_STATUS_OPTIMIZING = 3
DATASTORE_OPTIMIZATION_STATUS_DELETED = 4

_DATASTORE = _descriptor.Descriptor(
    name='Datastore',
    full_name='grid.v1.Datastore',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Datastore.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Datastore.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Datastore.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=121,
    serialized_end=273,
)

_DATASTORESPEC = _descriptor.Descriptor(
    name='DatastoreSpec',
    full_name='grid.v1.DatastoreSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.DatastoreSpec.user_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='name',
            full_name='grid.v1.DatastoreSpec.name',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='name',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='version',
            full_name='grid.v1.DatastoreSpec.version',
            index=2,
            number=3,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='version',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='source',
            full_name='grid.v1.DatastoreSpec.source',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='source',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.DatastoreSpec.desired_state',
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='uploaded_at',
            full_name='grid.v1.DatastoreSpec.uploaded_at',
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='uploadedAt',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.DatastoreSpec.cluster_id',
            index=6,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='size_mib',
            full_name='grid.v1.DatastoreSpec.size_mib',
            index=7,
            number=8,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sizeMib',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='datastore_type',
            full_name='grid.v1.DatastoreSpec.datastore_type',
            index=8,
            number=9,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='datastoreType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=276,
    serialized_end=656,
)

_DATASTORESOURCE = _descriptor.Descriptor(
    name='DatastoreSource',
    full_name='grid.v1.DatastoreSource',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='dsn',
            full_name='grid.v1.DatastoreSource.dsn',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dsn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='source',
            full_name='grid.v1.DatastoreSource.source',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=658,
    serialized_end=705,
)

_DATASTORESTATUS = _descriptor.Descriptor(
    name='DatastoreStatus',
    full_name='grid.v1.DatastoreStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='phase',
            full_name='grid.v1.DatastoreStatus.phase',
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phase',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='size_bytes',
            full_name='grid.v1.DatastoreStatus.size_bytes',
            index=1,
            number=2,
            type=4,
            cpp_type=4,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sizeBytes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='snapshot_id',
            full_name='grid.v1.DatastoreStatus.snapshot_id',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='snapshotId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='extracted_url',
            full_name='grid.v1.DatastoreStatus.extracted_url',
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='extractedUrl',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=708,
    serialized_end=916,
)

_DATASTORESNAPSHOTID = _descriptor.Descriptor(
    name='DatastoreSnapshotID',
    full_name='grid.v1.DatastoreSnapshotID',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.DatastoreSnapshotID.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='k8s_volume_snapshot_name',
            full_name='grid.v1.DatastoreSnapshotID.k8s_volume_snapshot_name',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='k8sVolumeSnapshotName',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='id',
            full_name='grid.v1.DatastoreSnapshotID.id',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=919,
    serialized_end=1057,
)

_DATASTOREINPUT = _descriptor.Descriptor(
    name='DatastoreInput',
    full_name='grid.v1.DatastoreInput',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='dsn',
            full_name='grid.v1.DatastoreInput.dsn',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dsn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='mount_path',
            full_name='grid.v1.DatastoreInput.mount_path',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='mountPath',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1059,
    serialized_end=1124,
)

_DATASTORE.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_DATASTORE.fields_by_name['spec'].message_type = _DATASTORESPEC
_DATASTORE.fields_by_name['status'].message_type = _DATASTORESTATUS
_DATASTORESPEC.fields_by_name['source'].message_type = _DATASTORESOURCE
_DATASTORESPEC.fields_by_name['desired_state'].enum_type = _DATASTORESTATE
_DATASTORESPEC.fields_by_name['uploaded_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DATASTORESPEC.fields_by_name['datastore_type'].enum_type = _DATASTORETYPE
_DATASTORESOURCE.oneofs_by_name['source'].fields.append(_DATASTORESOURCE.fields_by_name['dsn'])
_DATASTORESOURCE.fields_by_name['dsn'].containing_oneof = _DATASTORESOURCE.oneofs_by_name['source']
_DATASTORESTATUS.fields_by_name['phase'].enum_type = _DATASTOREOPTIMIZATIONSTATUS
_DATASTORESTATUS.fields_by_name['snapshot_id'].message_type = _DATASTORESNAPSHOTID
_DATASTORESNAPSHOTID.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DATASTORESNAPSHOTID.oneofs_by_name['id'].fields.append(_DATASTORESNAPSHOTID.fields_by_name['external'])
_DATASTORESNAPSHOTID.fields_by_name['external'].containing_oneof = _DATASTORESNAPSHOTID.oneofs_by_name['id']
_DATASTORESNAPSHOTID.oneofs_by_name['id'].fields.append(_DATASTORESNAPSHOTID.fields_by_name['k8s_volume_snapshot_name'])
_DATASTORESNAPSHOTID.fields_by_name['k8s_volume_snapshot_name'].containing_oneof = _DATASTORESNAPSHOTID.oneofs_by_name[
    'id']
DESCRIPTOR.message_types_by_name['Datastore'] = _DATASTORE
DESCRIPTOR.message_types_by_name['DatastoreSpec'] = _DATASTORESPEC
DESCRIPTOR.message_types_by_name['DatastoreSource'] = _DATASTORESOURCE
DESCRIPTOR.message_types_by_name['DatastoreStatus'] = _DATASTORESTATUS
DESCRIPTOR.message_types_by_name['DatastoreSnapshotID'] = _DATASTORESNAPSHOTID
DESCRIPTOR.message_types_by_name['DatastoreInput'] = _DATASTOREINPUT
DESCRIPTOR.enum_types_by_name['DatastoreType'] = _DATASTORETYPE
DESCRIPTOR.enum_types_by_name['DatastoreState'] = _DATASTORESTATE
DESCRIPTOR.enum_types_by_name['DatastoreOptimizationStatus'] = _DATASTOREOPTIMIZATIONSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Datastore = _reflection.GeneratedProtocolMessageType(
    'Datastore',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTORE,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Datastore)
    }
)
_sym_db.RegisterMessage(Datastore)

DatastoreSpec = _reflection.GeneratedProtocolMessageType(
    'DatastoreSpec',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTORESPEC,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSpec)
    }
)
_sym_db.RegisterMessage(DatastoreSpec)

DatastoreSource = _reflection.GeneratedProtocolMessageType(
    'DatastoreSource',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTORESOURCE,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSource)
    }
)
_sym_db.RegisterMessage(DatastoreSource)

DatastoreStatus = _reflection.GeneratedProtocolMessageType(
    'DatastoreStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTORESTATUS,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DatastoreStatus)
    }
)
_sym_db.RegisterMessage(DatastoreStatus)

DatastoreSnapshotID = _reflection.GeneratedProtocolMessageType(
    'DatastoreSnapshotID',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTORESNAPSHOTID,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DatastoreSnapshotID)
    }
)
_sym_db.RegisterMessage(DatastoreSnapshotID)

DatastoreInput = _reflection.GeneratedProtocolMessageType(
    'DatastoreInput',
    (_message.Message, ),
    {
        'DESCRIPTOR': _DATASTOREINPUT,
        '__module__': 'grid.v1.datastore_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.DatastoreInput)
    }
)
_sym_db.RegisterMessage(DatastoreInput)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/experiment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import enum_type_wrapper

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

from grid.protos.grid.v1 import datastore_pb2 as grid_dot_v1_dot_datastore__pb2
from grid.protos.grid.v1 import image_pb2 as grid_dot_v1_dot_image__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name='grid/v1/experiment.proto',
    package='grid.v1',
    syntax='proto3',
    serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
    create_key=_descriptor._internal_create_key,
    serialized_pb=
    b'\n\x18grid/v1/experiment.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x17grid/v1/datastore.proto\x1a\x13grid/v1/image.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x9b\x01\n\nExperiment\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x17.grid.v1.ExperimentSpecR\x04spec\x12\x31\n\x06status\x18\x03 \x01(\x0b\x32\x19.grid.v1.ExperimentStatusR\x06status\"F\n\x0cScratchSpace\x12\x17\n\x07size_gb\x18\x01 \x01(\rR\x06sizeGb\x12\x1d\n\nmount_path\x18\x02 \x01(\tR\tmountPath\"\xc1\x05\n\x0e\x45xperimentSpec\x12\x32\n\x03\x65nv\x18\x01 \x03(\x0b\x32 .grid.v1.ExperimentSpec.EnvEntryR\x03\x65nv\x12\x37\n\x08\x65xecutor\x18\x02 \x01(\x0b\x32\x1b.grid.v1.ExperimentExecutorR\x08\x65xecutor\x12=\n\rdesired_state\x18\x04 \x01(\x0e\x32\x18.grid.v1.ExperimentStateR\x0c\x64\x65siredState\x12\x15\n\x06run_id\x18\x06 \x01(\tR\x05runId\x12\x17\n\x07user_id\x18\x07 \x01(\tR\x06userId\x12>\n\x0bsource_code\x18\x08 \x01(\x0b\x32\x1d.grid.v1.ExperimentSourceCodeR\nsourceCode\x12\x18\n\x07\x63ommand\x18\t \x03(\tR\x07\x63ommand\x12\x30\n\x14relative_working_dir\x18\n \x01(\tR\x12relativeWorkingDir\x12\x44\n\tresources\x18\x0b \x03(\x0b\x32&.grid.v1.ExperimentSpec.ResourcesEntryR\tresources\x12/\n\x06inputs\x18\x0c \x03(\x0b\x32\x17.grid.v1.DatastoreInputR\x06inputs\x12)\n\x10pause_automation\x18\r \x01(\x08R\x0fpauseAutomation\x12/\n\x07scratch\x18\x0e \x03(\x0b\x32\x15.grid.v1.ScratchSpaceR\x07scratch\x1a\x36\n\x08\x45nvEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a<\n\x0eResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xb2\x02\n\x12\x45xperimentExecutor\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x32\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12G\n\nkubernetes\x18\x03 \x01(\x0b\x32%.grid.v1.ExperimentKubernetesExecutorH\x00R\nkubernetes\x12\x38\n\x05slurm\x18\x04 \x01(\x0b\x32 .grid.v1.ExperimentSLURMExecutorH\x00R\x05slurm\x12:\n\tscheduler\x18\x05 \x01(\x0b\x32\x1c.grid.v1.ExperimentSchedulerR\tschedulerB\n\n\x08\x65xecutor\"\x94\x01\n\x13\x45xperimentScheduler\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12<\n\x06simple\x18\x02 \x01(\x0b\x32\".grid.v1.SimpleExperimentSchedulerH\x00R\x06simpleB\x0b\n\tscheduler\"J\n\x19SimpleExperimentScheduler\x12-\n\x12\x63\x61ndidate_clusters\x18\x01 \x03(\tR\x11\x63\x61ndidateClusters\"(\n\x14\x45xperimentSourceCode\x12\x10\n\x03\x64sn\x18\x01 \x01(\tR\x03\x64sn\"\x88\x01\n\x1c\x45xperimentKubernetesExecutor\x12#\n\rinstance_type\x18\x01 \x01(\tR\x0cinstanceType\x12\x19\n\x08use_spot\x18\x02 \x01(\x08R\x07useSpot\x12(\n\x05image\x18\x03 \x01(\x0b\x32\x12.grid.v1.ImageSpecR\x05image\"\x19\n\x17\x45xperimentSLURMExecutor\"\xed\x02\n\x10\x45xperimentStatus\x12.\n\x05phase\x18\x01 \x01(\x0e\x32\x18.grid.v1.ExperimentStateR\x05phase\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12\x45\n\x10\x66inish_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inishTimestamp\x12J\n\x0f\x65xecutor_status\x18\x04 \x01(\x0b\x32!.grid.v1.ExperimentExecutorStatusR\x0e\x65xecutorStatus\x12\x37\n\x06reason\x18\x05 \x01(\x0e\x32\x1f.grid.v1.ExperimentStatusReasonR\x06reason\x12\x18\n\x07message\x18\x06 \x01(\tR\x07message\"\xe9\x01\n\x18\x45xperimentExecutorStatus\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x45\n\nkubernetes\x18\x02 \x01(\x0b\x32#.grid.v1.ExperimentKubernetesStatusH\x00R\nkubernetes\x12\x36\n\x05slurm\x18\x03 \x01(\x0b\x32\x1e.grid.v1.ExperimentSLURMStatusH\x00R\x05slurmB\x1a\n\x18\x65xecutor_specific_status\"2\n\x1a\x45xperimentKubernetesStatus\x12\x14\n\x05image\x18\x01 \x01(\tR\x05image\"\x17\n\x15\x45xperimentSLURMStatus*\xc9\x02\n\x0f\x45xperimentState\x12 \n\x1c\x45XPERIMENT_STATE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x45XPERIMENT_STATE_PENDING\x10\x01\x12\x1b\n\x17\x45XPERIMENT_STATE_QUEUED\x10\x02\x12\x1c\n\x18\x45XPERIMENT_STATE_RUNNING\x10\x03\x12\x1e\n\x1a\x45XPERIMENT_STATE_SUCCEEDED\x10\x04\x12\x1b\n\x17\x45XPERIMENT_STATE_FAILED\x10\x05\x12\x1e\n\x1a\x45XPERIMENT_STATE_CANCELLED\x10\x06\x12\x1c\n\x18\x45XPERIMENT_STATE_DELETED\x10\x07\x12\x1b\n\x17\x45XPERIMENT_STATE_PAUSED\x10\x08\x12#\n\x1f\x45XPERIMENT_STATE_IMAGE_BUILDING\x10\t*\xf3\x01\n\x16\x45xperimentStatusReason\x12(\n$EXPERIMENT_STATUS_REASON_UNSPECIFIED\x10\x00\x12)\n%EXPERIMENT_STATUS_REASON_IMAGE_QUEUED\x10\x01\x12+\n\'EXPERIMENT_STATUS_REASON_IMAGE_BUILDING\x10\x02\x12,\n(EXPERIMENT_STATUS_REASON_IMAGE_COMPLETED\x10\x03\x12)\n%EXPERIMENT_STATUS_REASON_IMAGE_FAILED\x10\x04\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3',
    dependencies=[
        grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,
        grid_dot_v1_dot_datastore__pb2.DESCRIPTOR,
        grid_dot_v1_dot_image__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ]
)

_EXPERIMENTSTATE = _descriptor.EnumDescriptor(
    name='ExperimentState',
    full_name='grid.v1.ExperimentState',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_PENDING',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_QUEUED',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_RUNNING',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_SUCCEEDED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_FAILED',
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_CANCELLED',
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_DELETED',
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_PAUSED',
            index=8,
            number=8,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATE_IMAGE_BUILDING',
            index=9,
            number=9,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2531,
    serialized_end=2860,
)
_sym_db.RegisterEnumDescriptor(_EXPERIMENTSTATE)

ExperimentState = enum_type_wrapper.EnumTypeWrapper(_EXPERIMENTSTATE)
_EXPERIMENTSTATUSREASON = _descriptor.EnumDescriptor(
    name='ExperimentStatusReason',
    full_name='grid.v1.ExperimentStatusReason',
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATUS_REASON_UNSPECIFIED',
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATUS_REASON_IMAGE_QUEUED',
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATUS_REASON_IMAGE_BUILDING',
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATUS_REASON_IMAGE_COMPLETED',
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.EnumValueDescriptor(
            name='EXPERIMENT_STATUS_REASON_IMAGE_FAILED',
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2863,
    serialized_end=3106,
)
_sym_db.RegisterEnumDescriptor(_EXPERIMENTSTATUSREASON)

ExperimentStatusReason = enum_type_wrapper.EnumTypeWrapper(_EXPERIMENTSTATUSREASON)
EXPERIMENT_STATE_UNSPECIFIED = 0
EXPERIMENT_STATE_PENDING = 1
EXPERIMENT_STATE_QUEUED = 2
EXPERIMENT_STATE_RUNNING = 3
EXPERIMENT_STATE_SUCCEEDED = 4
EXPERIMENT_STATE_FAILED = 5
EXPERIMENT_STATE_CANCELLED = 6
EXPERIMENT_STATE_DELETED = 7
EXPERIMENT_STATE_PAUSED = 8
EXPERIMENT_STATE_IMAGE_BUILDING = 9
EXPERIMENT_STATUS_REASON_UNSPECIFIED = 0
EXPERIMENT_STATUS_REASON_IMAGE_QUEUED = 1
EXPERIMENT_STATUS_REASON_IMAGE_BUILDING = 2
EXPERIMENT_STATUS_REASON_IMAGE_COMPLETED = 3
EXPERIMENT_STATUS_REASON_IMAGE_FAILED = 4

_EXPERIMENT = _descriptor.Descriptor(
    name='Experiment',
    full_name='grid.v1.Experiment',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='metadata',
            full_name='grid.v1.Experiment.metadata',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='metadata',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='spec',
            full_name='grid.v1.Experiment.spec',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='spec',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='status',
            full_name='grid.v1.Experiment.status',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='status',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=168,
    serialized_end=323,
)

_SCRATCHSPACE = _descriptor.Descriptor(
    name='ScratchSpace',
    full_name='grid.v1.ScratchSpace',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='size_gb',
            full_name='grid.v1.ScratchSpace.size_gb',
            index=0,
            number=1,
            type=13,
            cpp_type=3,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sizeGb',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='mount_path',
            full_name='grid.v1.ScratchSpace.mount_path',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='mountPath',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=325,
    serialized_end=395,
)

_EXPERIMENTSPEC_ENVENTRY = _descriptor.Descriptor(
    name='EnvEntry',
    full_name='grid.v1.ExperimentSpec.EnvEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.ExperimentSpec.EnvEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.ExperimentSpec.EnvEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=987,
    serialized_end=1041,
)

_EXPERIMENTSPEC_RESOURCESENTRY = _descriptor.Descriptor(
    name='ResourcesEntry',
    full_name='grid.v1.ExperimentSpec.ResourcesEntry',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='key',
            full_name='grid.v1.ExperimentSpec.ResourcesEntry.key',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='key',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='value',
            full_name='grid.v1.ExperimentSpec.ResourcesEntry.value',
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='value',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b'8\001',
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1043,
    serialized_end=1103,
)

_EXPERIMENTSPEC = _descriptor.Descriptor(
    name='ExperimentSpec',
    full_name='grid.v1.ExperimentSpec',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='env',
            full_name='grid.v1.ExperimentSpec.env',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='env',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='executor',
            full_name='grid.v1.ExperimentSpec.executor',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='executor',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='desired_state',
            full_name='grid.v1.ExperimentSpec.desired_state',
            index=2,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='desiredState',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='run_id',
            full_name='grid.v1.ExperimentSpec.run_id',
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='runId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='user_id',
            full_name='grid.v1.ExperimentSpec.user_id',
            index=4,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='userId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='source_code',
            full_name='grid.v1.ExperimentSpec.source_code',
            index=5,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='sourceCode',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='command',
            full_name='grid.v1.ExperimentSpec.command',
            index=6,
            number=9,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='command',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='relative_working_dir',
            full_name='grid.v1.ExperimentSpec.relative_working_dir',
            index=7,
            number=10,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='relativeWorkingDir',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='resources',
            full_name='grid.v1.ExperimentSpec.resources',
            index=8,
            number=11,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='resources',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='inputs',
            full_name='grid.v1.ExperimentSpec.inputs',
            index=9,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='inputs',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='pause_automation',
            full_name='grid.v1.ExperimentSpec.pause_automation',
            index=10,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='pauseAutomation',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='scratch',
            full_name='grid.v1.ExperimentSpec.scratch',
            index=11,
            number=14,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='scratch',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[
        _EXPERIMENTSPEC_ENVENTRY,
        _EXPERIMENTSPEC_RESOURCESENTRY,
    ],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=398,
    serialized_end=1103,
)

_EXPERIMENTEXECUTOR = _descriptor.Descriptor(
    name='ExperimentExecutor',
    full_name='grid.v1.ExperimentExecutor',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='cluster_id',
            full_name='grid.v1.ExperimentExecutor.cluster_id',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='clusterId',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ExperimentExecutor.external',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes',
            full_name='grid.v1.ExperimentExecutor.kubernetes',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='slurm',
            full_name='grid.v1.ExperimentExecutor.slurm',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='slurm',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='scheduler',
            full_name='grid.v1.ExperimentExecutor.scheduler',
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='scheduler',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='executor',
            full_name='grid.v1.ExperimentExecutor.executor',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=1106,
    serialized_end=1412,
)

_EXPERIMENTSCHEDULER = _descriptor.Descriptor(
    name='ExperimentScheduler',
    full_name='grid.v1.ExperimentScheduler',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ExperimentScheduler.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='simple',
            full_name='grid.v1.ExperimentScheduler.simple',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='simple',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='scheduler',
            full_name='grid.v1.ExperimentScheduler.scheduler',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=1415,
    serialized_end=1563,
)

_SIMPLEEXPERIMENTSCHEDULER = _descriptor.Descriptor(
    name='SimpleExperimentScheduler',
    full_name='grid.v1.SimpleExperimentScheduler',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='candidate_clusters',
            full_name='grid.v1.SimpleExperimentScheduler.candidate_clusters',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='candidateClusters',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1565,
    serialized_end=1639,
)

_EXPERIMENTSOURCECODE = _descriptor.Descriptor(
    name='ExperimentSourceCode',
    full_name='grid.v1.ExperimentSourceCode',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='dsn',
            full_name='grid.v1.ExperimentSourceCode.dsn',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='dsn',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1641,
    serialized_end=1681,
)

_EXPERIMENTKUBERNETESEXECUTOR = _descriptor.Descriptor(
    name='ExperimentKubernetesExecutor',
    full_name='grid.v1.ExperimentKubernetesExecutor',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='instance_type',
            full_name='grid.v1.ExperimentKubernetesExecutor.instance_type',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='instanceType',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='use_spot',
            full_name='grid.v1.ExperimentKubernetesExecutor.use_spot',
            index=1,
            number=2,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='useSpot',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='image',
            full_name='grid.v1.ExperimentKubernetesExecutor.image',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='image',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1684,
    serialized_end=1820,
)

_EXPERIMENTSLURMEXECUTOR = _descriptor.Descriptor(
    name='ExperimentSLURMExecutor',
    full_name='grid.v1.ExperimentSLURMExecutor',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1822,
    serialized_end=1847,
)

_EXPERIMENTSTATUS = _descriptor.Descriptor(
    name='ExperimentStatus',
    full_name='grid.v1.ExperimentStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='phase',
            full_name='grid.v1.ExperimentStatus.phase',
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='phase',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='start_timestamp',
            full_name='grid.v1.ExperimentStatus.start_timestamp',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='startTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='finish_timestamp',
            full_name='grid.v1.ExperimentStatus.finish_timestamp',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='finishTimestamp',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='executor_status',
            full_name='grid.v1.ExperimentStatus.executor_status',
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='executorStatus',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='reason',
            full_name='grid.v1.ExperimentStatus.reason',
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='reason',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='message',
            full_name='grid.v1.ExperimentStatus.message',
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='message',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=1850,
    serialized_end=2215,
)

_EXPERIMENTEXECUTORSTATUS = _descriptor.Descriptor(
    name='ExperimentExecutorStatus',
    full_name='grid.v1.ExperimentExecutorStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='external',
            full_name='grid.v1.ExperimentExecutorStatus.external',
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='external',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='kubernetes',
            full_name='grid.v1.ExperimentExecutorStatus.kubernetes',
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='kubernetes',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
        _descriptor.FieldDescriptor(
            name='slurm',
            full_name='grid.v1.ExperimentExecutorStatus.slurm',
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='slurm',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name='executor_specific_status',
            full_name='grid.v1.ExperimentExecutorStatus.executor_specific_status',
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[]
        ),
    ],
    serialized_start=2218,
    serialized_end=2451,
)

_EXPERIMENTKUBERNETESSTATUS = _descriptor.Descriptor(
    name='ExperimentKubernetesStatus',
    full_name='grid.v1.ExperimentKubernetesStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name='image',
            full_name='grid.v1.ExperimentKubernetesStatus.image',
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode('utf-8'),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            json_name='image',
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2453,
    serialized_end=2503,
)

_EXPERIMENTSLURMSTATUS = _descriptor.Descriptor(
    name='ExperimentSLURMStatus',
    full_name='grid.v1.ExperimentSLURMStatus',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[],
    serialized_start=2505,
    serialized_end=2528,
)

_EXPERIMENT.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_EXPERIMENT.fields_by_name['spec'].message_type = _EXPERIMENTSPEC
_EXPERIMENT.fields_by_name['status'].message_type = _EXPERIMENTSTATUS
_EXPERIMENTSPEC_ENVENTRY.containing_type = _EXPERIMENTSPEC
_EXPERIMENTSPEC_RESOURCESENTRY.containing_type = _EXPERIMENTSPEC
_EXPERIMENTSPEC.fields_by_name['env'].message_type = _EXPERIMENTSPEC_ENVENTRY
_EXPERIMENTSPEC.fields_by_name['executor'].message_type = _EXPERIMENTEXECUTOR
_EXPERIMENTSPEC.fields_by_name['desired_state'].enum_type = _EXPERIMENTSTATE
_EXPERIMENTSPEC.fields_by_name['source_code'].message_type = _EXPERIMENTSOURCECODE
_EXPERIMENTSPEC.fields_by_name['resources'].message_type = _EXPERIMENTSPEC_RESOURCESENTRY
_EXPERIMENTSPEC.fields_by_name['inputs'].message_type = grid_dot_v1_dot_datastore__pb2._DATASTOREINPUT
_EXPERIMENTSPEC.fields_by_name['scratch'].message_type = _SCRATCHSPACE
_EXPERIMENTEXECUTOR.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTEXECUTOR.fields_by_name['kubernetes'].message_type = _EXPERIMENTKUBERNETESEXECUTOR
_EXPERIMENTEXECUTOR.fields_by_name['slurm'].message_type = _EXPERIMENTSLURMEXECUTOR
_EXPERIMENTEXECUTOR.fields_by_name['scheduler'].message_type = _EXPERIMENTSCHEDULER
_EXPERIMENTEXECUTOR.oneofs_by_name['executor'].fields.append(_EXPERIMENTEXECUTOR.fields_by_name['external'])
_EXPERIMENTEXECUTOR.fields_by_name['external'].containing_oneof = _EXPERIMENTEXECUTOR.oneofs_by_name['executor']
_EXPERIMENTEXECUTOR.oneofs_by_name['executor'].fields.append(_EXPERIMENTEXECUTOR.fields_by_name['kubernetes'])
_EXPERIMENTEXECUTOR.fields_by_name['kubernetes'].containing_oneof = _EXPERIMENTEXECUTOR.oneofs_by_name['executor']
_EXPERIMENTEXECUTOR.oneofs_by_name['executor'].fields.append(_EXPERIMENTEXECUTOR.fields_by_name['slurm'])
_EXPERIMENTEXECUTOR.fields_by_name['slurm'].containing_oneof = _EXPERIMENTEXECUTOR.oneofs_by_name['executor']
_EXPERIMENTSCHEDULER.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTSCHEDULER.fields_by_name['simple'].message_type = _SIMPLEEXPERIMENTSCHEDULER
_EXPERIMENTSCHEDULER.oneofs_by_name['scheduler'].fields.append(_EXPERIMENTSCHEDULER.fields_by_name['external'])
_EXPERIMENTSCHEDULER.fields_by_name['external'].containing_oneof = _EXPERIMENTSCHEDULER.oneofs_by_name['scheduler']
_EXPERIMENTSCHEDULER.oneofs_by_name['scheduler'].fields.append(_EXPERIMENTSCHEDULER.fields_by_name['simple'])
_EXPERIMENTSCHEDULER.fields_by_name['simple'].containing_oneof = _EXPERIMENTSCHEDULER.oneofs_by_name['scheduler']
_EXPERIMENTKUBERNETESEXECUTOR.fields_by_name['image'].message_type = grid_dot_v1_dot_image__pb2._IMAGESPEC
_EXPERIMENTSTATUS.fields_by_name['phase'].enum_type = _EXPERIMENTSTATE
_EXPERIMENTSTATUS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENTSTATUS.fields_by_name['finish_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENTSTATUS.fields_by_name['executor_status'].message_type = _EXPERIMENTEXECUTORSTATUS
_EXPERIMENTSTATUS.fields_by_name['reason'].enum_type = _EXPERIMENTSTATUSREASON
_EXPERIMENTEXECUTORSTATUS.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTEXECUTORSTATUS.fields_by_name['kubernetes'].message_type = _EXPERIMENTKUBERNETESSTATUS
_EXPERIMENTEXECUTORSTATUS.fields_by_name['slurm'].message_type = _EXPERIMENTSLURMSTATUS
_EXPERIMENTEXECUTORSTATUS.oneofs_by_name['executor_specific_status'].fields.append(
    _EXPERIMENTEXECUTORSTATUS.fields_by_name['external']
)
_EXPERIMENTEXECUTORSTATUS.fields_by_name['external'].containing_oneof = _EXPERIMENTEXECUTORSTATUS.oneofs_by_name[
    'executor_specific_status']
_EXPERIMENTEXECUTORSTATUS.oneofs_by_name['executor_specific_status'].fields.append(
    _EXPERIMENTEXECUTORSTATUS.fields_by_name['kubernetes']
)
_EXPERIMENTEXECUTORSTATUS.fields_by_name['kubernetes'].containing_oneof = _EXPERIMENTEXECUTORSTATUS.oneofs_by_name[
    'executor_specific_status']
_EXPERIMENTEXECUTORSTATUS.oneofs_by_name['executor_specific_status'].fields.append(
    _EXPERIMENTEXECUTORSTATUS.fields_by_name['slurm']
)
_EXPERIMENTEXECUTORSTATUS.fields_by_name['slurm'].containing_oneof = _EXPERIMENTEXECUTORSTATUS.oneofs_by_name[
    'executor_specific_status']
DESCRIPTOR.message_types_by_name['Experiment'] = _EXPERIMENT
DESCRIPTOR.message_types_by_name['ScratchSpace'] = _SCRATCHSPACE
DESCRIPTOR.message_types_by_name['ExperimentSpec'] = _EXPERIMENTSPEC
DESCRIPTOR.message_types_by_name['ExperimentExecutor'] = _EXPERIMENTEXECUTOR
DESCRIPTOR.message_types_by_name['ExperimentScheduler'] = _EXPERIMENTSCHEDULER
DESCRIPTOR.message_types_by_name['SimpleExperimentScheduler'] = _SIMPLEEXPERIMENTSCHEDULER
DESCRIPTOR.message_types_by_name['ExperimentSourceCode'] = _EXPERIMENTSOURCECODE
DESCRIPTOR.message_types_by_name['ExperimentKubernetesExecutor'] = _EXPERIMENTKUBERNETESEXECUTOR
DESCRIPTOR.message_types_by_name['ExperimentSLURMExecutor'] = _EXPERIMENTSLURMEXECUTOR
DESCRIPTOR.message_types_by_name['ExperimentStatus'] = _EXPERIMENTSTATUS
DESCRIPTOR.message_types_by_name['ExperimentExecutorStatus'] = _EXPERIMENTEXECUTORSTATUS
DESCRIPTOR.message_types_by_name['ExperimentKubernetesStatus'] = _EXPERIMENTKUBERNETESSTATUS
DESCRIPTOR.message_types_by_name['ExperimentSLURMStatus'] = _EXPERIMENTSLURMSTATUS
DESCRIPTOR.enum_types_by_name['ExperimentState'] = _EXPERIMENTSTATE
DESCRIPTOR.enum_types_by_name['ExperimentStatusReason'] = _EXPERIMENTSTATUSREASON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Experiment = _reflection.GeneratedProtocolMessageType(
    'Experiment',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENT,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.Experiment)
    }
)
_sym_db.RegisterMessage(Experiment)

ScratchSpace = _reflection.GeneratedProtocolMessageType(
    'ScratchSpace',
    (_message.Message, ),
    {
        'DESCRIPTOR': _SCRATCHSPACE,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ScratchSpace)
    }
)
_sym_db.RegisterMessage(ScratchSpace)

ExperimentSpec = _reflection.GeneratedProtocolMessageType(
    'ExperimentSpec',
    (_message.Message, ),
    {
        'EnvEntry':
        _reflection.GeneratedProtocolMessageType(
            'EnvEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _EXPERIMENTSPEC_ENVENTRY,
                '__module__': 'grid.v1.experiment_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSpec.EnvEntry)
            }
        ),
        'ResourcesEntry':
        _reflection.GeneratedProtocolMessageType(
            'ResourcesEntry',
            (_message.Message, ),
            {
                'DESCRIPTOR': _EXPERIMENTSPEC_RESOURCESENTRY,
                '__module__': 'grid.v1.experiment_pb2'
                # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSpec.ResourcesEntry)
            }
        ),
        'DESCRIPTOR':
        _EXPERIMENTSPEC,
        '__module__':
        'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSpec)
    }
)
_sym_db.RegisterMessage(ExperimentSpec)
_sym_db.RegisterMessage(ExperimentSpec.EnvEntry)
_sym_db.RegisterMessage(ExperimentSpec.ResourcesEntry)

ExperimentExecutor = _reflection.GeneratedProtocolMessageType(
    'ExperimentExecutor',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTEXECUTOR,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentExecutor)
    }
)
_sym_db.RegisterMessage(ExperimentExecutor)

ExperimentScheduler = _reflection.GeneratedProtocolMessageType(
    'ExperimentScheduler',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSCHEDULER,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentScheduler)
    }
)
_sym_db.RegisterMessage(ExperimentScheduler)

SimpleExperimentScheduler = _reflection.GeneratedProtocolMessageType(
    'SimpleExperimentScheduler',
    (_message.Message, ),
    {
        'DESCRIPTOR': _SIMPLEEXPERIMENTSCHEDULER,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.SimpleExperimentScheduler)
    }
)
_sym_db.RegisterMessage(SimpleExperimentScheduler)

ExperimentSourceCode = _reflection.GeneratedProtocolMessageType(
    'ExperimentSourceCode',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSOURCECODE,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSourceCode)
    }
)
_sym_db.RegisterMessage(ExperimentSourceCode)

ExperimentKubernetesExecutor = _reflection.GeneratedProtocolMessageType(
    'ExperimentKubernetesExecutor',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTKUBERNETESEXECUTOR,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentKubernetesExecutor)
    }
)
_sym_db.RegisterMessage(ExperimentKubernetesExecutor)

ExperimentSLURMExecutor = _reflection.GeneratedProtocolMessageType(
    'ExperimentSLURMExecutor',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSLURMEXECUTOR,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSLURMExecutor)
    }
)
_sym_db.RegisterMessage(ExperimentSLURMExecutor)

ExperimentStatus = _reflection.GeneratedProtocolMessageType(
    'ExperimentStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSTATUS,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentStatus)
    }
)
_sym_db.RegisterMessage(ExperimentStatus)

ExperimentExecutorStatus = _reflection.GeneratedProtocolMessageType(
    'ExperimentExecutorStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTEXECUTORSTATUS,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentExecutorStatus)
    }
)
_sym_db.RegisterMessage(ExperimentExecutorStatus)

ExperimentKubernetesStatus = _reflection.GeneratedProtocolMessageType(
    'ExperimentKubernetesStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTKUBERNETESSTATUS,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentKubernetesStatus)
    }
)
_sym_db.RegisterMessage(ExperimentKubernetesStatus)

ExperimentSLURMStatus = _reflection.GeneratedProtocolMessageType(
    'ExperimentSLURMStatus',
    (_message.Message, ),
    {
        'DESCRIPTOR': _EXPERIMENTSLURMSTATUS,
        '__module__': 'grid.v1.experiment_pb2'
        # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSLURMStatus)
    }
)
_sym_db.RegisterMessage(ExperimentSLURMStatus)

DESCRIPTOR._options = None
_EXPERIMENTSPEC_ENVENTRY._options = None
_EXPERIMENTSPEC_RESOURCESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import experiment_service_pb2 as grid_dot_v1_dot_experiment__service__pb2


class ExperimentServiceStub(object):
    # missing associated documentation comment in .proto file
    pass

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateExperiment = channel.unary_unary(
            '/grid.v1.ExperimentService/CreateExperiment',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.CreateExperimentRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.CreateExperimentResponse.FromString,
        )
        self.GetExperiment = channel.unary_unary(
            '/grid.v1.ExperimentService/GetExperiment',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.GetExperimentRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.GetExperimentResponse.FromString,
        )
        self.ListExperiments = channel.unary_unary(
            '/grid.v1.ExperimentService/ListExperiments',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.ListExperimentsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.ListExperimentsResponse.FromString,
        )
        self.UpdateExperiment = channel.unary_unary(
            '/grid.v1.ExperimentService/UpdateExperiment',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentResponse.FromString,
        )
        self.UpdateExperimentStatus = channel.unary_unary(
            '/grid.v1.ExperimentService/UpdateExperimentStatus',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentStatusRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentStatusResponse.FromString,
        )
        self.DeleteExperiment = channel.unary_unary(
            '/grid.v1.ExperimentService/DeleteExperiment',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.DeleteExperimentRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.DeleteExperimentResponse.FromString,
        )
        self.WatchExperiments = channel.unary_stream(
            '/grid.v1.ExperimentService/WatchExperiments',
            request_serializer=grid_dot_v1_dot_experiment__service__pb2.WatchExperimentsRequest.SerializeToString,
            response_deserializer=grid_dot_v1_dot_experiment__service__pb2.WatchExperimentsResponse.FromString,
        )


class ExperimentServiceServicer(object):
    # missing associated documentation comment in .proto file
    pass

    def CreateExperiment(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExperiment(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExperiments(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateExperiment(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateExperimentStatus(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteExperiment(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WatchExperiments(self, request, context):
        # missing associated documentation comment in .proto file
        pass
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExperimentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'CreateExperiment':
        grpc.unary_unary_rpc_method_handler(
            servicer.CreateExperiment,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.CreateExperimentRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.CreateExperimentResponse.SerializeToString,
        ),
        'GetExperiment':
        grpc.unary_unary_rpc_method_handler(
            servicer.GetExperiment,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.GetExperimentRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.GetExperimentResponse.SerializeToString,
        ),
        'ListExperiments':
        grpc.unary_unary_rpc_method_handler(
            servicer.ListExperiments,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.ListExperimentsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.ListExperimentsResponse.SerializeToString,
        ),
        'UpdateExperiment':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateExperiment,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentResponse.SerializeToString,
        ),
        'UpdateExperimentStatus':
        grpc.unary_unary_rpc_method_handler(
            servicer.UpdateExperimentStatus,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentStatusRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.UpdateExperimentStatusResponse.
            SerializeToString,
        ),
        'DeleteExperiment':
        grpc.unary_unary_rpc_method_handler(
            servicer.DeleteExperiment,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.DeleteExperimentRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.DeleteExperimentResponse.SerializeToString,
        ),
        'WatchExperiments':
        grpc.unary_stream_rpc_method_handler(
            servicer.WatchExperiments,
            request_deserializer=grid_dot_v1_dot_experiment__service__pb2.WatchExperimentsRequest.FromString,
            response_serializer=grid_dot_v1_dot_experiment__service__pb2.WatchExperimentsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler('grid.v1.ExperimentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler, ))
